-- ======================================================================
-- ===   Sql Script for Database : faktura
-- ===
-- === Build : 442
-- ======================================================================

DROP database IF EXISTS faktura;

create database faktura character set utf8 COLLATE utf8_bin;

CREATE USER 'faktura'@'localhost' IDENTIFIED BY 'faktura';
GRANT ALL PRIVILEGES ON faktura.* TO 'faktura'@'localhost';

use faktura;
-- ======================================================================

DROP TABLE IF EXISTS BelegPositionen;
DROP TABLE IF EXISTS Baugruppe;
DROP TABLE IF EXISTS Teilzahlungen;
DROP TABLE IF EXISTS GewerkSummen;
DROP TABLE IF EXISTS Buchungen;
DROP TABLE IF EXISTS Belege;
DROP TABLE IF EXISTS Uebernahme;
DROP TABLE IF EXISTS VerleihPositionen;
DROP TABLE IF EXISTS Verleihung;
DROP TABLE IF EXISTS Zeiterfassung;
DROP TABLE IF EXISTS Kaufteile;
DROP TABLE IF EXISTS AnfragePositionen;
DROP TABLE IF EXISTS Anfragen;
DROP TABLE IF EXISTS Projekt;
DROP TABLE IF EXISTS Ansprechpartner;
DROP TABLE IF EXISTS NebenkostenAbschr;
DROP TABLE IF EXISTS NebenkostenAnBu;
DROP TABLE IF EXISTS Nebenkosten;
DROP TABLE IF EXISTS Abschr;
DROP TABLE IF EXISTS AnBu;
DROP TABLE IF EXISTS ArtikelKundenpreise;
DROP TABLE IF EXISTS Kunden;
DROP TABLE IF EXISTS EA;
DROP TABLE IF EXISTS Konten;
DROP TABLE IF EXISTS AboPositionen;
DROP TABLE IF EXISTS AboRechnung;
DROP TABLE IF EXISTS Aufmass;
DROP TABLE IF EXISTS VerleihArtikel;
DROP TABLE IF EXISTS Werbungskosten;
DROP TABLE IF EXISTS MusterPositionen;
DROP TABLE IF EXISTS Muster;
DROP TABLE IF EXISTS Firmenstamm;
DROP TABLE IF EXISTS NebenkostenObjekte;
DROP TABLE IF EXISTS Artikel;
DROP TABLE IF EXISTS Kontoarten;
DROP TABLE IF EXISTS MwSt;
DROP TABLE IF EXISTS AufEinheit;
DROP TABLE IF EXISTS AufTyp;
DROP TABLE IF EXISTS AufOperation;
DROP TABLE IF EXISTS LK;
DROP TABLE IF EXISTS gui;
DROP TABLE IF EXISTS Gewerk;
DROP TABLE IF EXISTS Abschlag;
DROP TABLE IF EXISTS WK_Person;
DROP TABLE IF EXISTS Tools;
DROP TABLE IF EXISTS Nummernkreis;
DROP TABLE IF EXISTS BJStatus;
DROP TABLE IF EXISTS AfaListe;
DROP TABLE IF EXISTS version;
DROP TABLE IF EXISTS Textvorlagen;
DROP TABLE IF EXISTS Anrede;
DROP TABLE IF EXISTS NebenkostenArten;
DROP TABLE IF EXISTS EA_Summe;
DROP TABLE IF EXISTS USt;
DROP TABLE IF EXISTS Buchungsarten;
DROP TABLE IF EXISTS Buchungsjahre;
DROP TABLE IF EXISTS Zahlung;
DROP TABLE IF EXISTS BelegStatus;
DROP TABLE IF EXISTS ZK;
DROP TABLE IF EXISTS ME;

-- ======================================================================

CREATE TABLE ME
  (
    ID_ME        int            not null,
    bezeichnung  varchar(255)   unique not null,

    primary key(ID_ME)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE ZK
  (
    ID_ZK        int            not null,
    bezeichnung  varchar(255)   unique not null,
    tage1        int            not null,
    prozent1     double         not null,
    tage2        int,
    prozent2     double,
    tage_netto   int            not null,

    primary key(ID_ZK)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE BelegStatus
  (
    ID_BelegStatus  int            not null,
    bezeichnung     varchar(255)   unique not null,

    primary key(ID_BelegStatus)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Zahlung
  (
    ID_Zahlung   int            not null,
    bezeichnung  varchar(255),

    primary key(ID_Zahlung)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Buchungsjahre
  (
    ID_Buchungsjahr  int            not null,
    Buchungsjahr     char(4)        unique not null,
    Status           int            not null,
    Saldo_VJ_Bank    double,
    Saldo_VJ_Kasse   double,
    archiv           varchar(255),

    primary key(ID_Buchungsjahr)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Buchungsarten
  (
    ID_Buchungsart  int            not null,
    buchungsart     varchar(255)   unique not null,

    primary key(ID_Buchungsart)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE USt
  (
    ID_Buchungsjahr  int            not null,
    Zeitraum         varchar(5)     not null,
    Text1            varchar(255),
    Text2            varchar(255),
    Text3            varchar(255),
    Text4            varchar(255),
    Text5            varchar(255),
    Netto1           double,
    Netto2           double,
    Netto3           double,
    Netto4           double,
    Netto5           double,
    MwSt1            double,
    MwSt2            double,
    MwSt3            double,
    MwSt4            double,
    MwSt5            double,
    Summe            double,
    Vorsteuer        double,
    Vorauszahlung    double,
    Datum            date,
    Zahlung          double,

    primary key(ID_Buchungsjahr,Zeitraum),

    foreign key(ID_Buchungsjahr) references Buchungsjahre(ID_Buchungsjahr)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE EA_Summe
  (
    ID_Buchungsjahr  int      not null,
    Einnahmen_b      double,
    Einnahmen_n      double,
    Einnahmen_m      double,
    Ausgaben_b       double,
    Ausgaben_n       double,
    Ausgaben_m       double,
    Abschreibung_b   double,
    Abschreibung_n   double,
    Abschreibung_m   double,
    MwSt_Anlageverm  double,
    Summe_b          double,
    Summe_n          double,
    Summe_m          double,

    primary key(ID_Buchungsjahr),

    foreign key(ID_Buchungsjahr) references Buchungsjahre(ID_Buchungsjahr)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE NebenkostenArten
  (
    ID_Nebenkostenart  int            not null,
    bezeichnung        varchar(255)   not null,

    primary key(ID_Nebenkostenart)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Anrede
  (
    ID_Anrede    int            not null,
    bezeichnung  varchar(255)   unique not null,

    primary key(ID_Anrede)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Textvorlagen
  (
    ID_Textvorlage  int,
    ID_Kunde        int,
    anrede          varchar(255),
    gruss           varchar(4096),

    primary key(ID_Textvorlage,ID_Kunde)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE version
  (
    version      varchar(255)   unique not null,
    datum        date           not null,
    versions_id  int            unique not null,

    primary key(version)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE AfaListe
  (
    Anlagegut  varchar(255)   not null,
    kauf       date,
    Afa1       double,
    BJ1        varchar(255),
    Afa2       double,
    BJ2        varchar(255),
    Afa3       double,
    BJ3        varchar(255),
    Afa4       double,
    BJ4        varchar(255),
    Afa5       double,
    BJ5        varchar(255),

    primary key(Anlagegut)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE BJStatus
  (
    ID_BJStatus  int            not null,
    bezeichnung  varchar(255)   unique not null,

    primary key(ID_BJStatus)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Nummernkreis
  (
    jahr    char(4)   unique not null,
    nummer  int       not null,

    primary key(jahr)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Tools
  (
    Beschreibung  varchar(255)    not null,
    Programm      varchar(4096)   not null,

    primary key(Beschreibung)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE WK_Person
  (
    ID_WK_Person  int,
    Name          varchar(255)   not null,

    primary key(ID_WK_Person)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Abschlag
  (
    ID_Beleg     int,
    ID_BelegPos  int,
    ID_Abschlag  int   unique,

    primary key(ID_Beleg,ID_BelegPos)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Gewerk
  (
    ID_Gewerk    int,
    Bezeichnung  varchar(255)   not null,

    primary key(ID_Gewerk)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE gui
  (
    neueGUI        int,
    tooltip        int,
    lookandfeel    int,
    spellchecking  int,
    freiberufler   int
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE LK
  (
    ID_LK            int            not null,
    bezeichnung      varchar(5)     unique not null,
    Langbezeichnung  varchar(255),
    Kurzbezeichnung  varchar(5),

    primary key(ID_LK)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE AufOperation
  (
    ID_AufOperation  int,
    Text             varchar(30)   unique not null,

    primary key(ID_AufOperation)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE AufTyp
  (
    ID_AufTyp  int,
    Text       varchar(30)   unique not null,

    primary key(ID_AufTyp)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE AufEinheit
  (
    ID_AufEinheit  int,
    Text           varchar(30)   unique not null,

    primary key(ID_AufEinheit)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE MwSt
  (
    ID_MwSt      int            not null,
    bezeichnung  varchar(255)   unique not null,
    faktor       double         not null,
    ID_LK        int,

    primary key(ID_MwSt),

    foreign key(ID_LK) references LK(ID_LK)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Kontoarten
  (
    ID_Kontoart  int            not null,
    bezeichnung  varchar(255)   not null,
    ID_Zahlung   int            not null,

    primary key(ID_Kontoart),

    foreign key(ID_Zahlung) references Zahlung(ID_Zahlung) on update RESTRICT on delete RESTRICT
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Artikel
  (
    ID_Artikel   int            not null,
    bezeichnung  varchar(255)   unique not null,
    nettopreis   double,
    ID_MwSt      int,
    ID_ME        int,
    kalkpreis    double,

    primary key(ID_Artikel),

    foreign key(ID_MwSt) references MwSt(ID_MwSt),
    foreign key(ID_ME) references ME(ID_ME)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE NebenkostenObjekte
  (
    ID_NebenkostenObjekt  int            not null,
    bezeichnung           varchar(255)   not null,
    ID_Nebenkostenart     int            not null,
    anteil                double,

    primary key(ID_NebenkostenObjekt),

    foreign key(ID_Nebenkostenart) references NebenkostenArten(ID_Nebenkostenart)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Firmenstamm
  (
    ID_Firmenstamm  int            not null,
    Firmenname      varchar(255)   unique not null,
    Strasse         varchar(255)   not null,
    PLZ             varchar(5)     not null,
    Ort             varchar(255)   not null,
    Telefon         varchar(30)    not null,
    Telefax         varchar(30)    not null,
    E_Mail          varchar(30)    not null,
    Bankverbindung  varchar(255)   not null,
    IBAN            varchar(255)   not null,
    BIC             varchar(30)    not null,
    Steuernummer    varchar(30)    not null,
    Absender        varchar(255),
    FA_Name         varchar(255),
    FA_Strasse      varchar(255),
    FA_PLZ          varchar(5),
    FA_Ort          varchar(255),
    Waehrung        varchar(5),
    ID_LK           int,
    Internet        varchar(255),

    primary key(ID_Firmenstamm),

    foreign key(ID_LK) references LK(ID_LK)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Muster
  (
    ID_Muster           INTEGER,
    netto               double          not null,
    mwst                double          not null,
    brutto              double          not null,
    ID_MwSt             int             not null,
    Belegtext           varchar(4096)   not null,
    ID_ZK               int             not null,
    ID_Artikel          int,
    Name                varchar(255)    not null,
    ID_Kunde            int             not null,
    ID_Ansprechpartner  int             not null,

    primary key(ID_Muster),

    foreign key(ID_MwSt) references MwSt(ID_MwSt),
    foreign key(ID_ZK) references ZK(ID_ZK),
    foreign key(ID_Artikel) references Artikel(ID_Artikel)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE MusterPositionen
  (
    ID_Beleg     INTEGER,
    ID_Pos       int,
    Text1        varchar(255),
    Text2        varchar(255),
    Anzahl       double         not null,
    Preis        double         not null,
    Summe        double         not null,
    Lieferdatum  date,
    ID_ME        int,

    primary key(ID_Beleg,ID_Pos),

    foreign key(ID_Beleg) references Muster(ID_Muster),
    foreign key(ID_ME) references ME(ID_ME)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Werbungskosten
  (
    ID_WKPerson        int,
    ID_Buchungsjahr    int,
    ID_Werbungskosten  int,
    datum              date,
    Text               varchar(255)   not null,
    Anzahl             double         not null,
    betrag             double         not null,
    summe              double         not null,

    primary key(ID_WKPerson,ID_Buchungsjahr,ID_Werbungskosten),

    foreign key(ID_WKPerson) references WK_Person(ID_WK_Person),
    foreign key(ID_Buchungsjahr) references Buchungsjahre(ID_Buchungsjahr)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE VerleihArtikel
  (
    ID_VerleihArtikel  int            not null,
    bezeichnung        varchar(255)   unique not null,
    seriennummer       varchar(255)   not null,
    bild               varchar(255),
    lagerort           varchar(255)   not null,
    nettoverleihpreis  double,
    ID_MwSt            int,
    ID_ME              int,
    status             int,

    primary key(ID_VerleihArtikel),

    foreign key(ID_MwSt) references MwSt(ID_MwSt),
    foreign key(ID_ME) references ME(ID_ME)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Aufmass
  (
    ID_Beleg         int            not null,
    ID_Pos           int            not null,
    ID_lfd           int            not null,
    Text             varchar(255)   not null,
    ID_AufOperation  int            not null,
    laenge           double         not null,
    breite           double         not null,
    ID_AufTyp        int            not null,
    ID_AufEinheit    int            not null,
    Datum            date           not null,
    flaeche          double,

    primary key(ID_Beleg,ID_Pos,ID_lfd),

    foreign key(ID_AufOperation) references AufOperation(ID_AufOperation),
    foreign key(ID_AufTyp) references AufTyp(ID_AufTyp),
    foreign key(ID_AufEinheit) references AufEinheit(ID_AufEinheit)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE AboRechnung
  (
    ID_AboRechnung      INTEGER,
    netto               double          not null,
    mwst                double          not null,
    brutto              double          not null,
    ID_MwSt             int             not null,
    Belegtext           varchar(4096)   not null,
    ID_ZK               int             not null,
    ID_Artikel          int,
    Name                varchar(255)    not null,
    ID_Kunde            int             not null,
    ID_Ansprechpartner  int             not null,

    primary key(ID_AboRechnung),

    foreign key(ID_MwSt) references MwSt(ID_MwSt),
    foreign key(ID_ZK) references ZK(ID_ZK),
    foreign key(ID_Artikel) references Artikel(ID_Artikel)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE AboPositionen
  (
    ID_Beleg     INTEGER,
    ID_Pos       int,
    Text1        varchar(255),
    Text2        varchar(255),
    Anzahl       double         not null,
    Preis        double         not null,
    Summe        double         not null,
    Lieferdatum  date,
    ID_ME        int,

    primary key(ID_Beleg,ID_Pos),

    foreign key(ID_Beleg) references AboRechnung(ID_AboRechnung),
    foreign key(ID_ME) references ME(ID_ME)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Konten
  (
    ID_Konto        int            not null,
    bezeichnung     varchar(255)   not null,
    ID_Kontoart     int            not null,
    ID_Buchungsart  int            not null,

    primary key(ID_Konto),

    foreign key(ID_Kontoart) references Kontoarten(ID_Kontoart) on update RESTRICT on delete RESTRICT,
    foreign key(ID_Buchungsart) references Buchungsarten(ID_Buchungsart) on update RESTRICT on delete RESTRICT
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE EA
  (
    ID_Buchungsjahr  int      not null,
    ID_Buchungsart   int      not null,
    ID_Konto         int      not null,
    brutto           double   not null,
    netto            double   not null,
    mwst             double   not null,

    primary key(ID_Buchungsjahr,ID_Buchungsart,ID_Konto),

    foreign key(ID_Buchungsjahr) references Buchungsjahre(ID_Buchungsjahr),
    foreign key(ID_Buchungsart) references Buchungsarten(ID_Buchungsart),
    foreign key(ID_Konto) references Konten(ID_Konto)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Kunden
  (
    ID_Kunde           int            not null,
    Art                int            not null,
    Name               varchar(255)   unique not null,
    Strasse            varchar(255)   not null,
    PLZ                varchar(255)   not null,
    Ort                varchar(255)   not null,
    anzKopien          int,
    EMail              varchar(255),
    Archivname         varchar(255),
    angelegt           date,
    Steuernummer       varchar(30),
    ID_LK              int,
    Lieferantennummer  varchar(255),
    ID_ZK              int,
    ID_Konto           int,

    primary key(ID_Kunde),

    foreign key(ID_LK) references LK(ID_LK),
    foreign key(ID_ZK) references ZK(ID_ZK),
    foreign key(ID_Konto) references Konten(ID_Konto)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE ArtikelKundenpreise
  (
    ID_Artikel  int      not null,
    ID_Kunde    int      not null,
    nettopreis  double   not null,

    primary key(ID_Artikel,ID_Kunde),

    foreign key(ID_Kunde) references Kunden(ID_Kunde)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE AnBu
  (
    ID_AnBu          int             not null,
    ID_Buchungsjahr  int             not null,
    ID_Kunde         int,
    Beschreibung     varchar(255)    not null,
    Afa_dauer        int             not null,
    kauf             date            not null,
    verkauf          date,
    brutto           double          not null,
    netto            double          not null,
    mwst             double,
    ID_MwSt          int             not null,
    pdfname          varchar(4096),

    primary key(ID_AnBu),

    foreign key(ID_Buchungsjahr) references Buchungsjahre(ID_Buchungsjahr),
    foreign key(ID_Kunde) references Kunden(ID_Kunde),
    foreign key(ID_MwSt) references MwSt(ID_MwSt)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Abschr
  (
    ID_AnBu          int      not null,
    ID_Buchungsjahr  int      not null,
    netto_afa        double   not null,

    primary key(ID_AnBu,ID_Buchungsjahr),

    foreign key(ID_AnBu) references AnBu(ID_AnBu),
    foreign key(ID_Buchungsjahr) references Buchungsjahre(ID_Buchungsjahr)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Nebenkosten
  (
    ID_Buchungsjahr       int            not null,
    ID_Nebenkosten        int            not null,
    ID_NebenkostenObjekt  int            not null,
    art                   int,
    Buchungstext          varchar(255),
    Belegdatum            date           not null,
    ID_Kunde              int            not null,
    brutto                double         not null,

    primary key(ID_Buchungsjahr,ID_Nebenkosten),

    foreign key(ID_Buchungsjahr) references Buchungsjahre(ID_Buchungsjahr) on update RESTRICT on delete RESTRICT,
    foreign key(ID_NebenkostenObjekt) references NebenkostenObjekte(ID_NebenkostenObjekt),
    foreign key(ID_Kunde) references Kunden(ID_Kunde) on update RESTRICT on delete RESTRICT
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE NebenkostenAnBu
  (
    ID_NebenkostenAnBu  int            not null,
    ID_Buchungsjahr     int            not null,
    ID_Kunde            int,
    Beschreibung        varchar(255)   not null,
    Afa_dauer           int            not null,
    kauf                date           not null,
    verkauf             date,
    brutto              double         not null,
    netto               double         not null,
    mwst                double,
    ID_MwSt             int            not null,

    primary key(ID_NebenkostenAnBu),

    foreign key(ID_Buchungsjahr) references Buchungsjahre(ID_Buchungsjahr),
    foreign key(ID_Kunde) references Kunden(ID_Kunde),
    foreign key(ID_MwSt) references MwSt(ID_MwSt)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE NebenkostenAbschr
  (
    ID_NebenkostenAnBu  int       not null,
    Buchungsjahr        char(4)   not null,
    netto_afa           double    not null,

    primary key(ID_NebenkostenAnBu,Buchungsjahr),

    foreign key(ID_NebenkostenAnBu) references AnBu(ID_AnBu)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Ansprechpartner
  (
    ID_Ansprechpartner  int            unique not null,
    ID_Kunde            int            not null,
    Name                varchar(255)   not null,
    Vorname             varchar(255)   not null,
    Telefon             varchar(255),
    EMail               varchar(255),
    ID_Anrede           int            not null,
    Funktion            varchar(255),

    primary key(ID_Ansprechpartner),

    foreign key(ID_Kunde) references Kunden(ID_Kunde),
    foreign key(ID_Anrede) references Anrede(ID_Anrede)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Projekt
  (
    id_projekt          int            unique not null,
    Projektbezeichnung  varchar(255)   not null,
    status              int            not null,
    ID_Kunde            int,
    einnahmen           double,
    ausgaben            double,
    saldo               double,

    primary key(id_projekt),

    foreign key(status) references BJStatus(ID_BJStatus),
    foreign key(ID_Kunde) references Kunden(ID_Kunde)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Anfragen
  (
    ID_Anfrage          int,
    ID_Lieferant        int            not null,
    ID_Ansprechpartner  int,
    ID_BelegStatus      int            not null,
    text                varchar(255),
    nummer              varchar(30),
    ID_ZK               int,
    DatAnfrage          date,
    DatBestellung       date,
    netto               double,
    DatBezahlt          date,

    primary key(ID_Anfrage),

    foreign key(ID_Lieferant) references Kunden(ID_Kunde),
    foreign key(ID_Ansprechpartner) references Ansprechpartner(ID_Ansprechpartner),
    foreign key(ID_BelegStatus) references BelegStatus(ID_BelegStatus),
    foreign key(ID_ZK) references ZK(ID_ZK)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE AnfragePositionen
  (
    ID_Anfrage  int,
    ID_Pos      int,
    anzahl      double         not null,
    ID_ME       int            not null,
    text        varchar(255),
    Preis       double,
    Summe       double,

    primary key(ID_Anfrage,ID_Pos),

    foreign key(ID_Anfrage) references Anfragen(ID_Anfrage),
    foreign key(ID_ME) references ME(ID_ME)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Kaufteile
  (
    ID_Kaufteil   int            not null,
    bezeichnung   varchar(255)   unique not null,
    anzahl        double,
    einzelpreis   double,
    ID_ME         int,
    nettopreis    double,
    ID_MwSt       int,
    ID_Lieferant  int,

    primary key(ID_Kaufteil),

    foreign key(ID_ME) references ME(ID_ME),
    foreign key(ID_MwSt) references MwSt(ID_MwSt),
    foreign key(ID_Lieferant) references Kunden(ID_Kunde)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Zeiterfassung
  (
    tag          varchar(30)    not null,
    ID_Projekt   int            not null,
    idx          int            not null,
    Bezeichnung  varchar(255)   not null,
    start        datetime,
    ende         datetime,
    gebucht      int            not null,

    primary key(tag,ID_Projekt,idx),

    foreign key(ID_Projekt) references Projekt(id_projekt)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Verleihung
  (
    ID_Verleihung  int    not null,
    ID_Kunde       int    not null,
    ausleihtag     date   not null,
    rueckgabetag   date   not null,
    anzahlTage     int    not null,

    primary key(ID_Verleihung),

    foreign key(ID_Kunde) references Kunden(ID_Kunde)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE VerleihPositionen
  (
    ID_Verleihung      int   not null,
    ID_Pos             int   not null,
    ID_VerleihArtikel  int   not null,

    primary key(ID_Verleihung,ID_Pos),

    foreign key(ID_Verleihung) references Verleihung(ID_Verleihung) on delete RESTRICT,
    foreign key(ID_VerleihArtikel) references VerleihArtikel(ID_VerleihArtikel)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Uebernahme
  (
    ID_Buchungsjahr  int             not null,
    ID_Uebernahme    int             not null,
    art              int,
    Buchungstext     varchar(255)    not null,
    Belegdatum       date            not null,
    ID_Konto         int,
    ID_Kunde         int,
    ID_MwSt          int,
    netto            double,
    mwst             double,
    brutto           double          not null,
    id_projekt       int,
    pdfname          varchar(4096),

    primary key(ID_Buchungsjahr,ID_Uebernahme),

    foreign key(ID_Buchungsjahr) references Buchungsjahre(ID_Buchungsjahr) on update RESTRICT on delete RESTRICT,
    foreign key(ID_Konto) references Konten(ID_Konto) on update RESTRICT on delete RESTRICT,
    foreign key(ID_Kunde) references Kunden(ID_Kunde) on update RESTRICT on delete RESTRICT,
    foreign key(ID_MwSt) references MwSt(ID_MwSt) on update RESTRICT on delete RESTRICT,
    foreign key(id_projekt) references Projekt(id_projekt)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Belege
  (
    ID_Beleg            int             not null,
    ID_Kunde            int             not null,
    ID_BelegStatus      int             not null,
    netto               double          not null,
    mwst                double          not null,
    brutto              double          not null,
    ID_MwSt             int             not null,
    Belegtext           varchar(4096)   not null,
    DatAngebot          date,
    DatLieferschein     date,
    DatRechnung         date,
    DatMahnung          date,
    DatBezahlt          date,
    ID_ZK               int             not null,
    rechnungsnummer     varchar(255)    not null,
    ID_Artikel          int,
    DatAB               date,
    ID_Ansprechpartner  int             not null,
    BestellnummerKunde  varchar(255),
    AbwLFirma           varchar(255),
    AbwLZusatz          varchar(255),
    AbwLStrasse         varchar(255),
    AbwLPlz             varchar(5),
    AbwLOrt             varchar(255),
    hatGewerk           int,
    AbwLand             varchar(255),

    primary key(ID_Beleg),

    foreign key(ID_Kunde) references Kunden(ID_Kunde) on delete RESTRICT,
    foreign key(ID_BelegStatus) references BelegStatus(ID_BelegStatus) on delete RESTRICT,
    foreign key(ID_MwSt) references MwSt(ID_MwSt) on delete RESTRICT,
    foreign key(ID_ZK) references ZK(ID_ZK) on delete RESTRICT,
    foreign key(ID_Artikel) references Artikel(ID_Artikel),
    foreign key(ID_Ansprechpartner) references Ansprechpartner(ID_Ansprechpartner)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Buchungen
  (
    ID_Buchungsjahr  int             not null,
    ID_Buchung       int             not null,
    art              int,
    Buchungstext     varchar(255),
    Belegdatum       date            not null,
    ID_Konto         int             not null,
    ID_Kunde         int             not null,
    ID_MwSt          int,
    netto            double          not null,
    mwst             double          not null,
    brutto           double          not null,
    id_projekt       int,
    pdfname          varchar(4096),

    primary key(ID_Buchungsjahr,ID_Buchung),

    foreign key(ID_Buchungsjahr) references Buchungsjahre(ID_Buchungsjahr) on update RESTRICT on delete RESTRICT,
    foreign key(ID_Konto) references Konten(ID_Konto) on update RESTRICT on delete RESTRICT,
    foreign key(ID_Kunde) references Kunden(ID_Kunde) on update RESTRICT on delete RESTRICT,
    foreign key(ID_MwSt) references MwSt(ID_MwSt) on update RESTRICT on delete RESTRICT,
    foreign key(id_projekt) references Projekt(id_projekt)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE GewerkSummen
  (
    ID_Beleg     int,
    ID_Gewerk    int,
    SummeNetto   double,
    SummeBrutto  double,

    primary key(ID_Beleg,ID_Gewerk),

    foreign key(ID_Beleg) references Belege(ID_Beleg),
    foreign key(ID_Gewerk) references Gewerk(ID_Gewerk)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Teilzahlungen
  (
    ID_Teilzahlung   int,
    ID_Beleg         int            not null,
    Zahlungseingang  date           not null,
    Text             varchar(255)   not null,
    Betrag           double         not null,
    ID_Buchung       int            not null,
    ID_Buchungsjahr  int            not null,

    primary key(ID_Teilzahlung),

    foreign key(ID_Beleg) references Belege(ID_Beleg)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE Baugruppe
  (
    ID_Artikel   int            not null,
    ID_Pos       int            not null,
    Bezeichnung  varchar(255)   not null,
    anzahl       double,
    ID_Kaufteil  int,
    netto        double,

    primary key(ID_Artikel,ID_Pos),

    foreign key(ID_Artikel) references Artikel(ID_Artikel),
    foreign key(ID_Kaufteil) references Kaufteile(ID_Kaufteil)
  )
 ENGINE = InnoDB;

-- ======================================================================

CREATE TABLE BelegPositionen
  (
    ID_Beleg     int            not null,
    ID_Pos       int            not null,
    Text1        varchar(255),
    Text2        varchar(255),
    Anzahl       double         not null,
    Preis        double         not null,
    Summe        double         not null,
    Lieferdatum  date,
    ID_ME        int,
    ID_Gewerk    int,

    primary key(ID_Beleg,ID_Pos),

    foreign key(ID_Beleg) references Belege(ID_Beleg) on delete RESTRICT,
    foreign key(ID_ME) references ME(ID_ME) on delete RESTRICT,
    foreign key(ID_Gewerk) references Gewerk(ID_Gewerk)
  )
 ENGINE = InnoDB;

-- ======================================================================

insert into ME (ID_ME, bezeichnung) values (1, 'Std.'), (2, 'Stck.'), (3, 'Tag');

insert into LK (ID_LK, bezeichnung, Langbezeichnung, Kurzbezeichnung) values (1, 'DE', 'Deutschland', 'D'), (2, 'AT', 'Österreich', 'A'), (3, 'CH', 'Schweitz', 'CH'), (4, 'IT', 'Italien', 'I');

insert into MwSt (ID_MwSt, bezeichnung, faktor, ID_LK) values (1, ' 7 %', 1.07, 1), (2, '16 %', 1.16, 1), (3, '19 %', 1.19, 1), (4, ' 0 %', 1.0, 1);
insert into MwSt (ID_MwSt, bezeichnung, faktor, ID_LK) values (5, '10 %', 1.10, 2), (6, '20 %', 1.2, 2), (7, '2,5 %', 1.025, 3), (8, '3,7 %', 1.037, 3), (9, '7,7 %', 1.077, 3);
insert into MwSt (ID_MwSt, bezeichnung, faktor, ID_LK) values (10, ' 4 %', 1.04, 4), (11, ' 10 %', 1.1, 4), (12, '21 %', 1.21, 4);

insert into ZK (ID_ZK, bezeichnung, tage1, prozent1, tage2, prozent2, tage_netto)
values (1, '10T2', 10, 2, 0, 0, 30), (2, '10T3', 10, 3, 0, 0, 30), (3, '8TN', 8, 0, 0, 0, 8);

insert into Zahlung (ID_Zahlung, bezeichnung) values (0, 'keine'), (1, 'Bank'), (2, 'Kasse'), (3, 'Privat');

insert into Kontoarten (ID_Kontoart, bezeichnung, ID_Zahlung)
values (1, 'B Einnahmen', 1), (2, 'B Ausgaben', 1), (3, 'K Einnahmen', 2), (4, 'K Ausgaben', 2),
       (5, 'P Einnahmen', 3), (6, 'P Ausgaben', 3), (7, 'Saldenkonto', 0), (8, 'MwSt-Zhlg.', 1),
       (9, 'MwSt-Erst.', 1), (10, 'Anlagevermögen', 1);

insert into Buchungsarten (ID_Buchungsart, buchungsart)
values (0, 'Anlagevermögen'), (1, 'Ausgaben'), (2, 'Einnahmen');

insert into Konten (ID_Konto, bezeichnung, ID_Kontoart, ID_Buchungsart)
values    (1,'Bank Vorjahressaldo',7,0),
   (3,'Anlagevermögen',10,0),
   (30,'Einkauf Kunden',2,1),
   (33,'Wartungskosten Hardware',2,1),
   (34,'Fachliteratur',2,1),
   (35,'Bürobedarf',2,1),
   (36,'Porto',2,1),
   (37,'Steuerberatung',2,1),
   (39,'Telekommunikation',2,1),
   (50,'Umsatzsteuerzahlungen',8,1),
   (80,'Umsatzerlöse Softwareentw.',1,2),
   (90,'MwSt-Erstattung',9,2);


insert into Buchungsjahre (ID_Buchungsjahr, Buchungsjahr, Status, Saldo_VJ_Bank, Saldo_VJ_Kasse)
values (1, '2017', 2, 0.0, 0.0), (2, '2018', 2, 0.0, 0.0), (3, '2019', 0, 0.0, 0.0), (4, '2020', 0, 0.0, 0.0);

insert into BelegStatus (ID_BelegStatus, bezeichnung)
values (10, 'Angebot'), (15, 'Auftragsbestätigung'), (20, 'Lieferschein'), (30, 'Rechnung'), (40, 'Mahnung'), (50, 'bezahlt'),
(110, 'Anfrage'), (120, 'Bestellung'), (150, 'erledigt'), (51, 'zurückgenommene Rechnung'), 
(60, 'Gutschrift'), (41, '2. Mahnung'), (42, '3. Mahnung'), (45, 'Letzte Mahnung'),
(69, 'bezahlte Gutschrift'),
(31, 'Abschlagsrechnung'), (32, 'Anzahlung'), (33, 'Schlussrechnung'), (35, 'Teilzahlung'),
(34, 'Korrekturrechnung');

insert into NebenkostenArten (ID_Nebenkostenart, bezeichnung)
values (1, 'personenbezogene NK');

insert into NebenkostenArten (ID_Nebenkostenart, bezeichnung)
values (2, 'Mietobjekte');

insert into NebenkostenArten (ID_Nebenkostenart, bezeichnung)
values (3, 'Arbeitszimmer');

insert into Anrede (ID_Anrede, bezeichnung)
values (0, 'undef.');

insert into Anrede (ID_Anrede, bezeichnung)
values (1, 'Herr');

insert into Anrede (ID_Anrede, bezeichnung)
values (2, 'Frau');

insert into Textvorlagen (ID_Textvorlage, anrede, gruss, ID_Kunde)
values (10, 'wir bedanken uns für Ihre Anfrage und erlauben uns Ihnen wie folgt anzubieten:\n\n',
		'Die Lieferzeit beträgt 4 Wochen nach schriftlichem Auftragseingang bzw. richtet sich nach persönlichen Ab-\nsprachen. Wir hoffen Ihren Vorstellungen mit unserer Offerte zu entsprechen und würden uns über Ihren\ngeschätzten Auftrag freuen.\n\nMit freundlichen Grüßen\nStefan Klemm', 0);
insert into Textvorlagen (ID_Textvorlage, anrede, gruss, ID_Kunde)
values (40, 'für unsere Rechnung konnten wir bis heute keinen Zahlungseingang feststellen.', 'Wir bitten um den Ausgleich der offenen Rechnung, da ansonsten zusätzliche  Kosten in Form von Mahngebühren anfallen.', 0);
insert into Textvorlagen (ID_Textvorlage, anrede, gruss, ID_Kunde)
values (41, 'auf unsere letzte Mahnung können wir noch immer keinen Zahlungseingang feststellen. Wir bitten um Ausgleich bis zum <TERMIN>.', 'Lieferungen für laufende Bestellungen werden bis zum Zahlungseingang ausgesetzt.', 0);
insert into Textvorlagen (ID_Textvorlage, anrede, gruss, ID_Kunde)
values (42, 'auf unsere letzten 2 Mahnungen konnten wir  keinen Zahlungseingang feststellen. Wir bitten um Ausgleich bis zum <TERMIN>', 'Bei Fristversäumnis müssen wir die Forderungen an unseren Rechtsanwalt übergeben. Dadurch entstehen für Sie zusätzliche Kosten.', 0);
insert into Textvorlagen (ID_Textvorlage, anrede, gruss, ID_Kunde)
values (45, 'leider könnten wir auch auf unser 3. Mahnung keinen Zahlungseingang feststellen.', 'Zu Ihrer Information teilen wir Ihnen mit, dass wir nunmehr diesen Sachverhalt unserem Rechtsanwalt übergeben haben. Die daraus entstehenden Kosten gehen zu Ihren Lasten.', 0);

insert into Textvorlagen (ID_Textvorlage, anrede, gruss, ID_Kunde)
values (60, 'Da Sie unsere Rechnung <RECHNUNG> bereits ausgeglichen haben, erstatten wir Ihnen den Betrag als Gutschrift.', 'Der Überweisungsauftrag wurde am <DATUM> erteilt.', 0); 

insert into Firmenstamm values (1, 'Ingenieurbüro Stefan Klemm', 'Buchhaldeweg 3', '87647', 'Unterthingau', '08377/929 555', '???', 'stefan@klemm.biz', 
'Stadtsparkasse Augsburg', 'IBAN', 'BIC', 'Steuernummer', '??', '', '', '', '', '€', 1, 'www.');

insert into BJStatus (ID_BJStatus, bezeichnung)
values (0, 'neu'), (1, 'offen'), (2, 'abgeschlossen');

insert into AufOperation (ID_AufOperation, Text)
values (1, 'Fläche'), (2, 'Abzug');

insert into AufTyp (ID_AufTyp, Text)
values (1, 'Bodenfläche'), (2, 'Wandfläche');

insert into AufEinheit (ID_AufEinheit, Text)
values (1, 'm'), (2, 'm²');

insert into version values ('1.80', now(), 80);
-- ======================================================================

